@@ -19,6 +19,7 @@ from trytond.model import ModelView, ModelSingleton, ModelSQL, fields
 from trytond.tools import safe_eval, datetime_strftime
 from trytond.transaction import Transaction
 from trytond.pyson import Eval
+from trytond.pool import Pool
 
 
 class Newborn(ModelSQL, ModelView):
@@ -129,19 +130,19 @@ class NeonatalApgar(ModelSQL, ModelView):
         ('0', 'No response to stimulation'),
         ('1', 'grimace when stimulated'),
         ('2', 'cry or pull away when stimulated'),
-        ], 'Grimace', required=True)
+        ], 'Grimace', required=True, sort=False)
 
     apgar_activity = fields.Selection([
         ('0', 'None'),
         ('1', 'Some flexion'),
         ('2', 'flexed arms and legs'),
-        ], 'Activity', required=True)
+        ], 'Activity', required=True, sort=False)
 
     apgar_respiration = fields.Selection([
         ('0', 'Absent'),
         ('1', 'Weak / Irregular'),
         ('2', 'strong'),
-        ], 'Respiration', required=True)
+        ], 'Respiration', required=True, sort=False)
 
     apgar_score = fields.Integer('APGAR Score',
         on_change_with=['apgar_respiration', 'apgar_activity',
@@ -431,7 +432,7 @@ class PediatricSymptomsChecklist(ModelSQL, ModelView):
         'psc_refuses_to_share'])
 
     def default_user_id(self):
-        user_obj = self.pool.get('res.user')
+        user_obj = Pool().get('res.user')
         user = user_obj.browse(Transaction().user)
         return int(user.id)
 
